@@ -102,6 +102,7 @@ class Connection(object):
         http_headers=None,
         http_scheme=constants.HTTP,
         auth=constants.DEFAULT_AUTH,
+        extra_credential=None,
         redirect_handler=None,
         max_attempts=constants.DEFAULT_MAX_ATTEMPTS,
         request_timeout=constants.DEFAULT_REQUEST_TIMEOUT,
@@ -125,6 +126,7 @@ class Connection(object):
         self.http_headers = http_headers
         self.http_scheme = http_scheme
         self.auth = auth
+        self.extra_credential = extra_credential
         self.redirect_handler = redirect_handler
         self.max_attempts = max_attempts
         self.request_timeout = request_timeout
@@ -188,6 +190,7 @@ class Connection(object):
             NO_TRANSACTION,
             self.http_scheme,
             self.auth,
+            self.extra_credential,
             self.redirect_handler,
             self.max_attempts,
             self.request_timeout,
@@ -199,6 +202,8 @@ class Connection(object):
             if self.transaction is None:
                 self.start_transaction()
             request = self.transaction._request
+        elif self.transaction is not None:
+            request = self.transaction._request
         else:
             request = self._create_request()
         return Cursor(self, request)
